==> qt-creator-opensource-src-3.4.0.tar.gz: qt-creator-opensource-src-3.4.0/src/plugins/git/gerrit/branchcombobox.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 Orgad Shaneh <orgads@gmail.com>.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "branchcombobox.h"
#include "../gitplugin.h"
#include "../gitclient.h"

using namespace Git::Internal;
using namespace Gerrit::Internal;

BranchComboBox::BranchComboBox(QWidget *parent) :
    QComboBox(parent),
    m_detached(false)
{
    m_client = GitPlugin::instance()->gitClient();
}

void BranchComboBox::init(const QString &repository)
{
    m_repository = repository;
    QString currentBranch = m_client->synchronousCurrentLocalBranch(repository);
    if (currentBranch.isEmpty()) {
        m_detached = true;
        currentBranch = QLatin1String("HEAD");
        addItem(currentBranch);
    }
    QString output;
    const QString branchPrefix(QLatin1String("refs/heads/"));
    QStringList args;
    args << QLatin1String("--format=%(refname)") << branchPrefix;
    if (!m_client->synchronousForEachRefCmd(m_repository, args, &output))
        return;
    QStringList branches = output.trimmed().split(QLatin1Char('\n'));
    foreach (const QString &ref, branches) {
        const QString branch = ref.mid(branchPrefix.size());
        addItem(branch);
    }
    if (currentBranch.isEmpty())
        return;
    int index = findText(currentBranch);
    if (index != -1)
        setCurrentIndex(index);
}

==> qt-creator-opensource-src-3.6.1.tar.gz: qt-creator-opensource-src-3.6.1/src/plugins/git/gerrit/branchcombobox.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 Orgad Shaneh <orgads@gmail.com>.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "branchcombobox.h"
#include "../gitplugin.h"
#include "../gitclient.h"

using namespace Git::Internal;
using namespace Gerrit::Internal;

BranchComboBox::BranchComboBox(QWidget *parent) :
    QComboBox(parent),
    m_detached(false)
{
    m_client = GitPlugin::instance()->client();
}

void BranchComboBox::init(const QString &repository)
{
    m_repository = repository;
    QString currentBranch = m_client->synchronousCurrentLocalBranch(repository);
    if (currentBranch.isEmpty()) {
        m_detached = true;
        currentBranch = QLatin1String("HEAD");
        addItem(currentBranch);
    }
    QString output;
    const QString branchPrefix(QLatin1String("refs/heads/"));
    QStringList args;
    args << QLatin1String("--format=%(refname)") << branchPrefix;
    if (!m_client->synchronousForEachRefCmd(m_repository, args, &output))
        return;
    QStringList branches = output.trimmed().split(QLatin1Char('\n'));
    foreach (const QString &ref, branches) {
        const QString branch = ref.mid(branchPrefix.size());
        addItem(branch);
    }
    if (currentBranch.isEmpty())
        return;
    int index = findText(currentBranch);
    if (index != -1)
        setCurrentIndex(index);
}
